@@ -24,7 +24,7 @@
 #include "kbookmarkmodel/commands.h"
 #include "kbookmarkmodel/model.h"
 
-#include <QDebug>
+#include "keditbookmarks_debug.h"
 #include <klocalizedstring.h>
 
 FavIconsItrHolder::FavIconsItrHolder(QObject* parent, KBookmarkModel* model)
@@ -52,7 +52,7 @@ void FavIconsItr::setStatus(const QString & status)
 
 void FavIconsItr::slotDone(bool succeeded, const QString& errorString)
 {
-    // //qDebug() << "FavIconsItr::slotDone()";
+    // //qCDebug(KEDITBOOKMARKS_LOG) << "FavIconsItr::slotDone()";
     setStatus(succeeded ? i18n("OK") : errorString);
     holder()->addAffectedBookmark(KBookmark::parentAddress(currentBookmark().address()));
     delayedEmitNextOne();
@@ -67,7 +67,7 @@ bool FavIconsItr::isApplicable(const KBookmark &bk) const
 
 void FavIconsItr::doAction()
 {
-    // //qDebug() << "FavIconsItr::doAction()";
+    // //qCDebug(KEDITBOOKMARKS_LOG) << "FavIconsItr::doAction()";
     m_oldStatus = currentBookmark().metaDataItem(QStringLiteral("favstate"));
     setStatus(i18n("Updating favicon..."));
     if (!m_updater) {
